# AngelQ Client

A python client for AngelQ APIs.

> Note: This is an initial release created to establish the `angelq-client` project on PyPI.
> Functionality will be expanded in future releases.

## Install

```bash
pip install angelq-client

